@@ -157,6 +157,13 @@ class PlcIO:
         return unpack(self.byteorder + str(num) + 'i',
                       self.cache.get(addr, 4*num))
 
+    def read_u64(self, addr):
+        return unpack(self.byteorder + 'Q', self.cache.get(addr, 8))[0]
+
+    def read_u64s(self, addr, num):
+        return unpack(self.byteorder + str(num) + 'Q',
+                      self.cache.get(addr, 8*num))
+
     def read_i64(self, addr):
         return unpack(self.byteorder + 'q', self.cache.get(addr, 8))[0]
 
