@@ -56,7 +56,7 @@ FLOAT32_MAX = 3.402823e+38
 FLOAT64_MAX = 1.7976931348623158e+308
 
 StatusStruct = BitFields(STATE=(15, 12), REASON=(11, 8), AUX=(7, 0))
-ParamControl = BitFields(CMD=(15, 13), SUBINDEX=(12, 8), IDX=(7, 0))
+ParamControl = BitFields(available=(15,15), CMD=(15, 13), SUBINDEX=(12, 8), IDX=(7, 0))
 
 ReasonMap = [
     '',
@@ -111,8 +111,8 @@ Parameters = ParamMap(
     CoderBits=3,
     ExtStatus=4,
     # HwOffset=5,
-    AbsMin=30,  # deprecated
-    AbsMax=31,  # deprecated
+    _AbsMin=30,  # deprecated
+    _AbsMax=31,  # deprecated
     UserMin=32,
     UserMax=33,
     WarnMin=34,
@@ -129,7 +129,7 @@ Parameters = ParamMap(
     DragError=55,
     Hysteresis=56,
     Holdback=57,
-    RefSpeed=58,
+    HomingSpeed=58,
     Jerk=59,
     Speed=60,
     Accel=61,
@@ -137,18 +137,18 @@ Parameters = ParamMap(
     RampCurrent=63,
     MoveCurrent=64,
     StopCurrent=65,
-    # AbortDecel=66,
-    LegacyMicrosteps=67,  # deprecated
+    # _AbortDecel=66,  # deprecated
+    _Microsteps=67,  # deprecated
     Slope=68,
-    RefPos=69,
+    HomePosition=69,
     Setpoint=70,
 
     # special functions
 
     FactoryReset=128,
-    RefMinus=131,  # deprecated
-    RefPlus=132,  # deprecated
-    Ref=133,
+    _RefMinus=131,  # deprecated
+    _RefPlus=132,  # deprecated
+    Home=133,
     SetPosition=137,
     ContMove=142,
 )
